==> file_access_via_webform-1.0.0.tar.gz: file_access_via_webform/src/Plugin/WebformHandler/WebformDownloadRedirectHandler.php <==
<?php

namespace Drupal\file_access_via_webform\Plugin\WebformHandler;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformHandlerBase;
use Drupal\webform\WebformSubmissionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;

/**
 * Webform handler for file access download redirect.
 *
 * @WebformHandler(
 *   id = "file_access_download_redirect",
 *   label = @Translation("File Access Download Redirect"),
 *   category = @Translation("File Access"),
 *   description = @Translation("Handles file download redirects after webform submission for controlled file access."),
 *   cardinality = \Drupal\webform\Plugin\WebformHandlerInterface::CARDINALITY_SINGLE,
 *   results = \Drupal\webform\Plugin\WebformHandlerInterface::RESULTS_PROCESSED,
 *   submission = \Drupal\webform\Plugin\WebformHandlerInterface::SUBMISSION_REQUIRED,
 * )
 */
class WebformDownloadRedirectHandler extends WebformHandlerBase {

  /**
   * The token manager.
   *
   * @var \Drupal\webform\WebformTokenManagerInterface
   */
  protected $tokenManager;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->tokenManager = $container->get('webform.token_manager');
    $instance->requestStack = $container->get('request_stack');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'hide_file_url' => FALSE,
      'debug' => FALSE,
      'file_disposition' => 'attachment',
      'download_message' => 'Your file is ready: <a href="@url">Click here to download</a>',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Download settings'),
      '#open' => FALSE,
    ];

    $form['settings']['file_disposition'] = [
      '#type' => 'select',
      '#title' => $this->t('File disposition'),
      '#description' => $this->t('Choose how the file should be displayed when accessed.'),
      '#options' => [
        'inline' => $this->t('Display in browser (inline)'),
        'attachment' => $this->t('Force download (attachment)'),
      ],
      '#default_value' => $this->configuration['file_disposition'],
    ];

    $form['settings']['download_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Download message'),
      '#description' => $this->t('Enter a custom message to display after the file is downloaded. Use @url to link to the file.'),
      '#default_value' => $this->configuration['download_message'],
      '#states' => [
        'visible' => [
          ':input[name="settings[file_disposition]"]' => ['value' => 'attachment'],
        ],
      ],
    ];

    $form['settings']['hide_file_url'] = [
      '#type' => 'select',
      '#title' => $this->t('File URL security'),
      '#description' => $this->t('Choose the security level for file URLs.'),
      '#options' => [
        FALSE => $this->t('Standard - Use direct file URLs'),
        TRUE => $this->t('Enhanced - Hide actual file URL and use secure token-based download route'),
      ],
      '#default_value' => $this->configuration['hide_file_url'],
    ];

    // Development settings.
    $form['development'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Development settings'),
    ];
    $form['development']['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable debugging'),
      '#description' => $this->t('If checked, every handler method invoked will be displayed onscreen to all users.'),
      '#return_value' => TRUE,
      '#default_value' => $this->configuration['debug'],
    ];

    return $this->setSettingsParents($form);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['hide_file_url'] = (bool) $form_state->getValue('hide_file_url');
    $this->configuration['debug'] = (bool) $form_state->getValue('debug');
    $this->configuration['file_disposition'] = $form_state->getValue('file_disposition');
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    $summary = parent::getSummary();

    // Add information about the file URL security setting.
    if (!empty($this->configuration['hide_file_url'])) {
      $summary[] = [
        '#markup' => $this->t('File URL security: <strong>Enhanced</strong> - Using secure token-based download URLs'),
      ];
    }
    else {
      $summary[] = [
        '#markup' => $this->t('File URL security: <strong>Standard</strong> - Using direct file URLs'),
      ];
    }

    // // Add information about the file disposition setting
    if ($this->configuration['file_disposition'] == 'attachment') {
      $summary[] = [
        '#markup' => '<br>' . $this->t('File disposition: <strong>Force download</strong> - Files will be downloaded rather than displayed in browser'),
      ];
    }
    else {
      $summary[] = [
        '#markup' => '<br>' . $this->t('File disposition: <strong>Inline</strong> - Files will be displayed in browser when possible'),
      ];
    }

    // Only display download message if force download is enabled.
    if ($this->configuration['file_disposition'] == 'attachment') {
      $summary[] = [
        '#markup' => '<br>' . $this->t('Download message: <strong> @url </strong>', ['@url' => $this->configuration['download_message']]),
      ];
    }

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function postSave(WebformSubmissionInterface $webform_submission, $update = TRUE) {
    // Always get source entity from request query parameters.
    $request = $this->requestStack->getCurrentRequest();
    $source_entity_type = $request->query->get('source_entity_type');
    $source_entity_id = $request->query->get('source_entity_id');

    if ($source_entity_type === 'file' && !empty($source_entity_id)) {
      $file = \Drupal::entityTypeManager()->getStorage('file')->load($source_entity_id);
      if ($file) {

        // Create the secure download URL.
        $url = NULL;
        if ($this->configuration['hide_file_url'] == TRUE) {
          // Generate a secure token for this download.
          $token = bin2hex(random_bytes(32));

          // Store the token in the session.
          \Drupal::service('session')->set('file_download_token_' . $source_entity_id, $token);

          // Store download settings in the session.
          $download_settings = [
            'disposition' => $this->configuration['file_disposition'],
          ];
          \Drupal::service('session')->set('file_download_settings_' . $source_entity_id, $download_settings);

          // Use secure download route if hide_file_url is enabled.
          $url = Url::fromRoute('file_access_via_webform.download', [
            'file_id' => $source_entity_id,
            'token' => $token,
          ])->toString();
        }
        else {
          // Use direct file URL if hide_file_url is disabled.
          $url = $file->createFileUrl(FALSE);
        }
        if ($this->configuration['file_disposition'] == 'attachment') {
          $message = $this->configuration['download_message'];
          $this->messenger()->addStatus(str_replace('@url', $url, $message));
        }
        else {
          $response = new RedirectResponse($url);
          $response->send();
        }
      }
    }
  }

  /**
   * Display the invoked plugin method to end user.
   *
   * @param string $method_name
   *   The invoked method name.
   * @param string $context1
   *   Additional parameter passed to the invoked method name.
   */
  protected function debug($method_name, $context1 = NULL) {
    if (!empty($this->configuration['debug'])) {
      $t_args = [
        '@id' => $this->getHandlerId(),
        '@class_name' => get_class($this),
        '@method_name' => $method_name,
        '@context1' => $context1,
      ];
      $this->messenger()->addWarning($this->t('Invoked @id: @class_name:@method_name @context1', $t_args), TRUE);
    }
  }

}

==> file_access_via_webform-1.0.2.tar.gz: file_access_via_webform/src/Plugin/WebformHandler/WebformDownloadRedirectHandler.php <==
<?php

namespace Drupal\file_access_via_webform\Plugin\WebformHandler;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformHandlerBase;
use Drupal\webform\WebformSubmissionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;

/**
 * Webform handler for file access download redirect.
 *
 * @WebformHandler(
 *   id = "file_access_download_redirect",
 *   label = @Translation("File Access Download Redirect"),
 *   category = @Translation("File Access"),
 *   description = @Translation("Handles file download redirects after webform submission for controlled file access."),
 *   cardinality = \Drupal\webform\Plugin\WebformHandlerInterface::CARDINALITY_SINGLE,
 *   results = \Drupal\webform\Plugin\WebformHandlerInterface::RESULTS_PROCESSED,
 *   submission = \Drupal\webform\Plugin\WebformHandlerInterface::SUBMISSION_REQUIRED,
 * )
 */
class WebformDownloadRedirectHandler extends WebformHandlerBase {

  /**
   * The token manager.
   *
   * @var \Drupal\webform\WebformTokenManagerInterface
   */
  protected $tokenManager;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->tokenManager = $container->get('webform.token_manager');
    $instance->requestStack = $container->get('request_stack');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'hide_file_url' => FALSE,
      'debug' => FALSE,
      'file_disposition' => 'attachment',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Download settings'),
      '#open' => FALSE,
    ];

    $form['settings']['file_disposition'] = [
      '#type' => 'select',
      '#title' => $this->t('File disposition'),
      '#description' => $this->t('Choose how the file should be displayed when accessed.'),
      '#options' => [
        'inline' => $this->t('Display in browser (inline)'),
        'attachment' => $this->t('Force download (attachment)'),
      ],
      '#default_value' => $this->configuration['file_disposition'],
    ];

    $form['settings']['hide_file_url'] = [
      '#type' => 'select',
      '#title' => $this->t('File URL security'),
      '#description' => $this->t('Choose the security level for file URLs.'),
      '#options' => [
        FALSE => $this->t('Standard - Use direct file URLs'),
        TRUE => $this->t('Enhanced - Hide actual file URL and use secure token-based download route'),
      ],
      '#default_value' => $this->configuration['hide_file_url'],
    ];

    // Development settings.
    $form['development'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Development settings'),
    ];
    $form['development']['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable debugging'),
      '#description' => $this->t('If checked, every handler method invoked will be displayed onscreen to all users.'),
      '#return_value' => TRUE,
      '#default_value' => $this->configuration['debug'],
    ];

    return $this->setSettingsParents($form);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['hide_file_url'] = (bool) $form_state->getValue('hide_file_url');
    $this->configuration['debug'] = (bool) $form_state->getValue('debug');
    $this->configuration['file_disposition'] = $form_state->getValue('file_disposition');
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    $summary = parent::getSummary();

    // Add information about the file URL security setting.
    if (!empty($this->configuration['hide_file_url'])) {
      $summary[] = [
        '#markup' => $this->t('File URL security: <strong>Enhanced</strong> - Using secure token-based download URLs'),
      ];
    }
    else {
      $summary[] = [
        '#markup' => $this->t('File URL security: <strong>Standard</strong> - Using direct file URLs'),
      ];
    }

    // // Add information about the file disposition setting
    if ($this->configuration['file_disposition'] == 'attachment') {
      $summary[] = [
        '#markup' => '<br>' . $this->t('File disposition: <strong>Force download</strong> - Files will be downloaded rather than displayed in browser'),
      ];
    }
    else {
      $summary[] = [
        '#markup' => '<br>' . $this->t('File disposition: <strong>Inline</strong> - Files will be displayed in browser when possible'),
      ];
    }

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function postSave(WebformSubmissionInterface $webform_submission, $update = TRUE) {
    // Always get source entity from request query parameters.
    $request = $this->requestStack->getCurrentRequest();
    $source_entity_type = $request->query->get('source_entity_type');
    $source_entity_id = $request->query->get('source_entity_id');

    if ($source_entity_type === 'file' && !empty($source_entity_id)) {
      $file = \Drupal::entityTypeManager()->getStorage('file')->load($source_entity_id);
      if ($file) {

        // Create the secure download URL.
        $url = NULL;
        if ($this->configuration['hide_file_url'] == TRUE) {
          // Generate a secure token for this download.
          $token = bin2hex(random_bytes(32));

          // Store the token in the session.
          \Drupal::service('session')->set('file_download_token_' . $source_entity_id, $token);

          // Store download settings in the session.
          $download_settings = [
            'disposition' => $this->configuration['file_disposition'],
          ];
          \Drupal::service('session')->set('file_download_settings_' . $source_entity_id, $download_settings);

          // Use secure download route if hide_file_url is enabled.
          $url = Url::fromRoute('file_access_via_webform.download', [
            'file_id' => $source_entity_id,
            'token' => $token,
          ])->toString();
        }
        else {
          // Use direct file URL if hide_file_url is disabled.
          $url = $file->createFileUrl(FALSE);
        }
        if ($this->configuration['file_disposition'] == 'attachment') {
          $this->messenger()->addStatus($this->t('Your file is ready: <a href="@url">Click here to download</a>', ['@url' => $url]));
        }
        else {
          $response = new RedirectResponse($url);
          $response->send();
        }
      }
    }
  }

  /**
   * Display the invoked plugin method to end user.
   *
   * @param string $method_name
   *   The invoked method name.
   * @param string $context1
   *   Additional parameter passed to the invoked method name.
   */
  protected function debug($method_name, $context1 = NULL) {
    if (!empty($this->configuration['debug'])) {
      $t_args = [
        '@id' => $this->getHandlerId(),
        '@class_name' => get_class($this),
        '@method_name' => $method_name,
        '@context1' => $context1,
      ];
      $this->messenger()->addWarning($this->t('Invoked @id: @class_name:@method_name @context1', $t_args), TRUE);
    }
  }

}
